---
description: Subscription & Billing FAQs
keywords: Docker, Docker Hub, billing FAQs, pull rate limiting FAQs, subscription, platform
title: Subscription & Billing FAQs
toc_min: 1
toc_max: 2
redirect_from:
- /docker-hub/billing/faq/
---

## Subscription tiers

### What subscriptions levels are available for Docker?

[Docker Subscriptions](https://www.docker.com/pricing/resource-consumption-updates){:target="blank" rel="noopener" class=""} come in three levels:
* **Free plans** for both individuals and development teams that include unlimited public repos.
* **Docker Pro subscriptions** for individuals with unlimited private repos, unlimited public repos, no rate limiting on pull requests and premium support starting at $5 per month with an annual subscription.
* **Docker Team subscriptions** for development teams with unlimited private repos and unlimited public repos starting at $25 per month for the first 5 users and $7 per month for each user thereafter with an Annual subscription. The Team plan offers advanced collaboration and management tools, including organization and team management with role-based access controls.

### What are the differences between Free, Pro and Team Subscriptions?

Pro and Team subscriptions feature additional features, support, consumption levels and more. You can compare programs at the [Docker Pricing](https://www.docker.com/pricing/faq){:target="blank" rel="noopener" class=""} page.

### How many seats do I need for my organization if I select a Team plan?

Your organization's number of paid seats must equal the number of organization members. If you're not using all of your organization's paid seats, you can downgrade to pay for fewer seats. Organization owners and members each fill a seat. If you've sent a pending invitation to a prospective organization member, the invitation will fill a seat.

### What are the rate limits for free subscriptions?

Anonymous and Free subscriptions are subject to rate limits on image pull requests. You can get more information at the [Rate Limiting Information](../docker-hub/download-rate-limit.md#how-do-i-authenticate-pull-requests){:target="blank" rel="noopener" class=""} page.

### We have a number of agents, users, and seats and it's difficult to track and manage the accounts. Can we get our organization IP addresses enabled for access instead?

We offer IP exclusions to allow for large organizations to use Docker platform services in diverse environments (developer laptops, CI systems, production systems, etc). Contact [Docker Sales](https://www.docker.com/pricing/questions){:target="blank" rel="noopener" class=""} for details and a price quote.

### What is a Docker ID? How do I get one?

A Docker ID is the core of a Docker subscription. You can get one for free at [Docker Hub](https://hub.docker.com){:target="blank" rel="noopener" class=""}.

### I want to buy a large number of Docker Team Subscription seats. How do I do this?

Contact the [Docker Sales Team ](https://goto.docker.com/pricing-question.html){:target="blank" rel="noopener" class=""} to buy a larger number of Docker Team Subscription seats.

### How do I access support? Do I have any extra benefits?

Docker Pro and Team subscribers have access to dedicated priority email support. All Docker subscribers (free and paid) have access to the Docker forums and Slack channels for community support.

### Do collaborator limits differ between the Free and Pro plans?

The Free plan includes unlimited collaborators for public repositories and zero collaborators for private repositories. Pro includes unlimited collaborators for public repositories and one unique collaborator for private repositories. Note that a collaborator on a private repository within a Pro plan can only be used with a service account. For details on the differences between plans, see the [Docker Pricing](https://www.docker.com/pricing){:target="blank" rel="noopener" class=""} page.

### Where can I renew my Docker Enterprise subscription?

The former Docker Enterprise product is now Mirantis Enterprise Platform. You can contact Mirantis for more information by visiting their [website](https://www.mirantis.com/){:target="blank" rel="noopener" class=""}.

### Does Docker offer academic pricing?

Contact the [Docker Sales Team](https://www.docker.com/company/contact){:target="blank" rel="noopener" class=""}.

### Can Docker Hub be used for free for open source projects?

Docker is a proud open source software company, and provides qualifying OSS software projects with access to Docker Hub with unlimited public repositories, unlimited consumption of OSS project container images, and unlimited collaborators at no cost. For questions about open source projects and pricing, visit the [Open Source Community Application](https://www.docker.com/community/open-source/application){:target="blank" rel="noopener" class=""}.

## Renewals, expansion, and account changes

### I’m on an annual plan. Where did my monthly seats go?

Docker no longer supports hybrid accounts with both monthly and annual seats. As of July 1, 2021, all monthly seats that were part of an existing annual plan have been converted to annual seats.

### How is Docker charging me for the monthly seats that were converted into annual seats?

Docker will not charge you for any monthly seats that were converted to annual seats for the remainder of your current annual subscription. We will charge you for the total number of seats included in your account at the time of the renewal of your annual subscription.

### Wait, so you’re saying I won’t be charged for my monthly seats for the remainder of my annual subscription?

That’s right! If you had monthly seats on your annual subscription, you won’t be charged for those seats until your annual renewal. For example, if you had five monthly seats on your annual subscription, and your annual subscription is renewing on December 1, 2021, you will not be charged for the five converted monthly seats until December 1, 2021.

### Do I need to do anything at the end of my subscription term?

No. All monthly and annual subscriptions are automatically renewed at the end of the term using the original form of payment.

### What happens if I pay for an annual subscription and add more users later?

When you add seats to your plan in the middle of your billing cycle, a prorated amount will be charged for the additional seats.

### How do I upgrade to a Pro plan from a legacy individual plan?

Upgrading your legacy plan to a Pro plan offers you unlimited public and private repos and 1 collaborator or service account. For information on how to upgrade to a Pro plan from a legacy plan, see the [How To Upgrade](upgrade.md){:target="blank" rel="noopener" class=""} page.

### How do I upgrade to a Team plan from a legacy organization plan?

Upgrading your legacy plan to a Team plan offers you unlimited private repos, unlimited teams, and 3 concurrent builds. For information on how to upgrade to a Team plan from a legacy (per-repository) plan, see the [How To Upgrade](upgrade.md){:target="blank" rel="noopener" class=""} page.

### How do downgrades from a Pro or Team plan work?
When you downgrade your Pro or Team plan, changes are applied at the end of your billing cycle. For example, if you are currently on a Team plan which is billed on the 8th of every month and you choose to downgrade to a Free Team plan on the 15th, your Team plan will be active until 7th of the following month. You will be transferred to a Free Team plan on the 8th of the following month. Please refer to the next two questions below for instructions on how to downgrade your account.

### How do I downgrade from a Team plan to a Free Team plan?

Before you downgrade to a Free plan, ensure that your organization details are updated to reflect features available in the Free plan. For example, you may need to reduce the number of team members and convert any private repositories to public repositories. For information on what’s included in the Free plan, see the [billing](index.md#pricing-plans){:target="blank" rel="noopener" class=""} page.

### How do I downgrade from Pro to a Free plan?

Before you downgrade to a Free plan, ensure that your account organization details are updated to reflect features available in the Free plan. For example, you may need to convert any private repositories to public repositories. For information on what’s included in the Free plan, see the [billing](downgrade.md){:target="blank" rel="noopener" class=""} page.

### How do I add a member to a team in my organization?

For information on how to add a member to a team, see [Add a member to a team](../docker-hub/orgs.md#add-a-member-to-a-team){:target="blank" rel="noopener" class=""}.

### What happens to my collaborators when I move to a free individual plan?

Free individual plans do not include collaborators for private repositories. If you have collaborators when you move to a free individual plan either from a paid plan or another free plan then you are required to remove all collaborators. If collaborators have not been removed within 30 days of moving to a free plan, all collaborators will automatically be removed from your account.

### What happens to my team members when I move to a free team plan?

Free team plans are allowed up to 3 members. If your team has more than three members when you move to a free team plan either from a paid plan or another free plan you are required to reduce your members to three. If your team size has not not been reduced to three within 30 days of moving to a free plan, all members will automatically be removed from your account. You will be able to add up to three members afterwards.

## Billing questions

### How can I get an invoice to purchase a Docker Team subscription?

Accounts with more than 500 seats can contact the Docker Large Account team for a proposal and invoice. For less than 500 seats, purchasing via credit card is the only option.

### How do I get a receipt for my subscription?

Customers receive a subscription confirmation with a link to their [billing plan](https://hub.docker.com/billing/plan){:target="blank" rel="noopener" class=""} page. From here you can navigate to the [billing history](https://hub.docker.com/billing/billing-history){:target="blank" rel="noopener" class=""} page to download invoices.

### Can I subscribe with a purchase order?

Accounts with more than 500 seats can contact the Docker Large Account team to subscribe with a purchase order. Subscriptions with fewer than 500 seats are purchased with a credit card.

### I have more questions regarding the new pricing, who can I reach out to?

If you have any questions that are not covered in the FAQ, please reach out and a member of the Docker team will get back to you.

### How does Docker Team Subscription pricing work?

Team starts at $25 per month for the first five users and $7 per month for each user thereafter with an annual subscription discount.

## Legacy repository account questions

### How will the new pricing plan impact existing Docker Hub customers?

Legacy individual and organizational repository customers have until their January 2021 billing cycle to switch to the new pricing plans.
To view the status of your individual repository plan, see [the billing](https://
hub.docker.com/billing/plan/update){:target="blank" rel="noopener" class=""} page.
To view the status of your organizational repository plan, see [Docker Hub Orgs](https://hub.docker.com/orgs){:target="blank" rel="noopener" class=""} page.

### What is the difference between the legacy repository plans and the newly announced plans?

The legacy plans were based on a private repository/parallel autobuild pricing model. The new Pro and Team plans are now based on a per-seat pricing model and include new features and consumption levels. Both Pro and Team offer unlimited private repos. The Free plan offers unlimited public repositories at no cost per month. You can see and compare the features in Free, Pro and Team subscriptions at the [Docker Pricing](https://www.docker.com/pricing){:target="blank" rel="noopener" class=""} page.

### If I am an existing paid Docker Hub customer, when do I need to change my plan?

If you are an existing Docker subscriber you have until your January 2021 billing date to move to the new pricing plans mentioned above. You can convert to either a Monthly plan or an Annual plan.

### How do I view my paid plans that need to be converted to new plans in January?

To view the status of your individual repository plan, see [Billing Plan Update](https://hub.docker.com/billing/plan/update){:target="blank" rel="noopener" class=""}.
To view the status of your organizational repository plan, see [Docker Hub Orgs](https://hub.docker.com/orgs){:target="blank" rel="noopener" class=""}.

### Will my price per month increase or decrease?

Depending on your configuration you may find it more economical to move to one of the new pricing plans available. For Teams, the key factor affecting a price increase or decrease is the total number of seats you need to support your organization. To optimize your subscription, review our discounted annual plan options, and remove any inactive org members listed in your organization.
Again, you can review your plans here:

To view the status of your individual repository plan, see [the billing](https://hub.docker.com/billing/plan/update){:target="blank" rel="noopener" class=""} page.
To view the status of your organizational repository plan, see [Docker Hub Orgs](https://hub.docker.com/orgs){:target="blank" rel="noopener" class=""}.

### If I am an existing subscriber but I don’t do anything by my January billing date, what will happen?

If no action is taken by the date, Docker will automatically upgrade you to an equivalent plan at the time of your monthly renewal date in the month of January 2021.
If you have an individual repository plan, with no contributors you will be converted to a monthly Pro plan.
If you have an organizational repository plan, you will be converted to a new per-seat monthly Team plan, with the current number of members in the organization.

### When will my legacy Docker plan convert to a new Docker Pro or Team Subscription?

When your legacy individual or organizational repository plan comes up for renewal in January 2021, your plan will be converted to the closest equivalent plan on the date of renewal. So if your plan renews on January 15th, your plan will convert on that date. All plans will be converted by January 31st, 2021.

To view the status of your individual repository plan, see [the billing](https://hub.docker.com/billing/plan/update){:target="blank" rel="noopener" class=""} page.

To view the status of your organizational repository plan, see [Docker Hub Orgs](https://hub.docker.com/orgs){:target="blank" rel="noopener" class=""}.

### What new features will I get in my seat-based subscription once I move from a legacy repository-based Docker subscription?

When your legacy individual or organizational repository plan comes up for renewal in January 2021, your plan will be converted to the closest equivalent plan on the date of renewal. So if your plan renews on January 15th, your plan will convert on that date. All plans will be converted by January 31st, 2021.

To view the status of your individual repository plan, see [the billing](https://hub.docker.com/billing/plan/update){:target="blank" rel="noopener" class=""} page.

To view the status of your organizational repository plan, see [Docker Hub Orgs](https://hub.docker.com/orgs){:target="blank" rel="noopener" class=""}.

### What new features will I get in my seat-based subscription once I move from a legacy repository-based Docker subscription?

Docker Pro and Docker Team subscriptions have a number of new features not available to repository-based accounts. Key new Docker platform features you will receive once your subscription migrates include:
More details are available at the [Docker Pricing](https://www.docker.com/pricing){:target="blank" rel="noopener" class=""} page.

* Unlimited private and public repositories
* Unlimited authenticated image pulls
* 3 Parallel auto-builds
* Role-based access controls
* Support for an unlimited number of teams
* Unlimited Hub image vulnerability scans
* Higher scan limits in Docker Desktop
* Audit Logs
* Slack notifications
* Premium customer support for Docker Desktop

### How do I know what new features are in planning for my Docker Pro or Docker Team subscription?

Docker maintains a [public roadmap](https://github.com/docker/roadmap){:target="blank" rel="noopener" class=""} so subscribers can see what new features are in development, as well as request new capabilities. New premium features will be available to you automatically as part of your migrated Docker subscription.

## Users and agents

### I want to run an automated agent that makes container requests on behalf of my organization. Which license do I need?

Automated agents or service accounts that make container image requests of Docker Hub must be licensed under a Docker Team subscription.

### What is a concurrent build?

Concurrent builds refer to the number of builds executing in parallel when using the Docker Hub Autobuild service, where you configure Hub to watch a github repo and rebuild images when changes are made.

## ISV programs and software distribution

### How can I ensure my customers can pull my software images without hitting rate limits?

Docker offers a number of programs for ISVs so their images can be pulled by developers without encountering rate limits. Contact [Docker Large Account sales](https://goto.docker.com/pricing-question.html){:target="blank" rel="noopener" class=""} for more information.

### How can I use Docker Hub as a private repository to distribute software to my customers?

ISVs can use Docker Hub to deliver images to their customers through a private repository as well. Accounts are seat-based, and allow a software vendor to restrict access to customers or other verified developers, while ensuring they can consume images without encountering rate limits. Contact [Docker Large Account sales](https://goto.docker.com/pricing-question.html){:target="blank" rel="noopener" class=""} for more information.

### How do I become a verified publisher?

Fill out the [Partner Application Form](https://www.docker.com/partners){:target="blank" rel="noopener" class=""} for more information and to start the process.

### I have more questions regarding the new pricing, who can I reach out to?

If you have any questions that are not covered in the FAQ, [please reach out](https://www.docker.com/company/contact){:target="blank" rel="noopener" class=""} and a member of the Docker team will get back to you.

<script type="application/ld+json">
{
  "@context": "https://schema.org",
  "@type": "FAQPage",
  "mainEntity": [
    {
      "@type": "Question",
      "name": "What subscriptions levels are available for Docker?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Docker Subscriptions come in three levels:\nFree plans for both individuals and development teams that include unlimited public repos.\nDocker Pro Subscriptions for individuals with unlimited private repos, unlimited public repos, no rate limiting on pull requests and premium support starting at $5/month with an annual subscription.\nDocker Team Subscriptions for development teams with unlimited private repos and unlimited public repos starting at $25 per month for the first 5 users and $7 per month for each user thereafter with an Annual subscription. The Team plan offers advanced collaboration and management tools, including organization and team management with role-based access controls.\n\n"
      }
    },
    {
      "@type": "Question",
      "name": "What are the differences between Free, Pro and Team Subscriptions?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Pro and Team subscriptions feature additional features, support, consumption levels and more. You can compare programs at the Docker Pricing Page."
      }
    },
    {
      "@type": "Question",
      "name": "How many seats do I need for my organization if I select a Team plan?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Your organization's number of paid seats must equal the number of organization members. If you're not using all of your organization's paid seats, you can downgrade to pay for fewer seats. Organization owners and members each fill a seat. If you've sent a pending invitation to a prospective organization member, the invitation will fill a seat."
      }
    },
    {
      "@type": "Question",
      "name": "What are the rate limits for free subscriptions?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Anonymous and Free subscriptions are subject to rate limits on container image pull requests. You can get more information at the Rate Limiting information page."
      }
    },
    {
      "@type": "Question",
      "name": "We have a number of agents, users, and seats and it's difficult to track and manage the accounts. Can we get our organization IP addresses enabled for access instead?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "We offer IP exclusions to allow for large organizations to use Docker platform services in diverse environments (developer laptops, CI systems, production systems, etc). Contact Docker Large Account sales for details and a price quote."
      }
    },
    {
      "@type": "Question",
      "name": "What is a Docker ID? How do I get one?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "A Docker ID is the core of a Docker subscription. You can get one for free at hub.docker.com."
      }
    },
    {
      "@type": "Question",
      "name": "I want to buy a large number of Docker Team Subscription seats. How do I do this?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Contact the Docker Large Account Team here."
      }
    },
    {
      "@type": "Question",
      "name": "How do I access support? Do I have any extra benefits?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Docker Pro and Team subscribers have access to dedicated priority email support. All Docker subscribers (free and paid) have access to the Docker forums and Slack channels for community support."
      }
    },
    {
      "@type": "Question",
      "name": "Do collaborator limits differ between the Free and Pro plans?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "The Free plan includes unlimited collaborators for public repositories and 0 collaborators for private repositories. Pro includes unlimited collaborators for public repositories and 1 unique collaborator for private repositories. Note that a collaborator on a private repository within a Pro plan can only be used with a service account. For details on the differences between plans, see https://www.docker.com/pricing."
      }
    },
     {
      "@type": "Question",
      "name": "Where can I renew my Docker Enterprise subscription?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "The former Docker Enterprise product is now Mirantis Enterprise Platform. You can contact Mirantis for more information by visiting their website www.mirantis.com"
      }
    },
    {
      "@type": "Question",
      "name": "Does Docker offer academic pricing?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Contact the Docker Sales Team."
      }
    },
    {
      "@type": "Question",
      "name": "Can Docker Hub be used for free for open source projects?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Docker is a proud open source software company, and provides qualifying OSS software projects with access to Docker Hub with unlimited public repositories unlimited consumption of OSS project container images and unlimited collaborators at no cost. For questions about open source projects and pricing please visit the Open Source Community Application."
      }
    },
    {
      "@type": "Question",
      "name": "How can I get an invoice to purchase a Docker Team subscription?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Accounts with more than 500 seats can contact the Docker Large Account team for a proposal and invoice. For less than 500 seats, purchasing via credit card is the only option."
      }
    },
    {
      "@type": "Question",
      "name": "How do I get a receipt for my subscription?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Customers receive a subscription confirmation with a link to their billing plan page (https://hub.docker.com/billing/plan). From here you can navigate to the billing history page (https://hub.docker.com/billing/billing-history) to download invoices."
      }
    },
    {
      "@type": "Question",
      "name": "Can I subscribe with a purchase order?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Accounts with more than 500 seats can contact the Docker Large Account team to subscribe with a purchase order. Subscriptions with fewer than 500 seats are purchased with a credit card."
      }
    },
    {
      "@type": "Question",
      "name": "I have more questions regarding the new pricing, who can I reach out to?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "If you have any questions that are not covered in the FAQ, please reach out and a member of the Docker team will get back to you."
      }
    },
    {
      "@type": "Question",
      "name": "How does Docker Team Subscription pricing work?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Team starts at $25 per month for the first 5 users and $7 per month for each user thereafter with an annual subscription discount."
      }
    }
  ]
}
</script>
